==> generator-octoblu-service-3.2.0.tgz: package/app/templates/README.md <==
# <%= (appname) %>

[![Dependency status](http://img.shields.io/david/octoblu/<%= _.slugify(appname) %>.svg?style=flat)](https://david-dm.org/octoblu/<%= _.slugify(appname) %>)
[![devDependency Status](http://img.shields.io/david/dev/octoblu/<%= _.slugify(appname) %>.svg?style=flat)](https://david-dm.org/octoblu/<%= _.slugify(appname) %>#info=devDependencies)
[![Build Status](http://img.shields.io/travis/octoblu/<%= _.slugify(appname) %>.svg?style=flat&branch=master)](https://travis-ci.org/octoblu/<%= _.slugify(appname) %>)

[![NPM](https://nodei.co/npm/<%= _.slugify(appname) %>.svg?style=flat)](https://npmjs.org/package/<%= _.slugify(appname) %>)

## Installing

```bash
$ npm install <%= _.slugify(appname) %>
```

### Usage

```javascript
console.log('hello world!');
```

## License

The MIT License (MIT)

Copyright 2015 Octoblu Inc.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.

==> generator-octoblu-service-3.3.2.tgz: package/app/templates/README.md <==
# <%= appName %>

[![Dependency status](http://img.shields.io/david/octoblu/<%= appName %>.svg?style=flat)](https://david-dm.org/octoblu/<%= appName %>)
[![devDependency Status](http://img.shields.io/david/dev/octoblu/<%= appName %>.svg?style=flat)](https://david-dm.org/octoblu/<%= appName %>#info=devDependencies)
[![Build Status](http://img.shields.io/travis/octoblu/<%= appName %>.svg?style=flat&branch=master)](https://travis-ci.org/octoblu/<%= appName %>)

[![NPM](https://nodei.co/npm/<%= appName %>.svg?style=flat)](https://npmjs.org/package/<%= appName %>)

## Installing

```bash
$ npm install <%= appName %>
```

### Usage

```javascript
console.log('hello world!');
```

## License

The MIT License (MIT)

Copyright 2016 Octoblu Inc.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
